@@ -1,23 +1,28 @@
 from django import forms
 from django.utils.translation import ugettext_lazy as _
+from django.template.defaultfilters import removetags
+from markupfield.widgets import MarkupTextarea
 from djinn_contenttypes.forms.base import PartialUpdateMixin
 from djinn_announcements.models.announcementupdate import AnnouncementUpdate
-from django.template.defaultfilters import removetags
 
 
 class AnnouncementUpdateForm(PartialUpdateMixin, forms.ModelForm):
 
-    date = forms.DateTimeField(label=_("Date"),
-                               widget=forms.DateTimeInput(
+    date = forms.DateTimeField(
+        label=_("Date"),
+        widget=forms.DateTimeInput(
             attrs={'class': 'datetime'},
             format="%d-%m-%Y %H:%M"
-            )
-                               )    
-    text = forms.CharField(label=_("Description"),
-                           max_length=150,
-                           help_text="Maximaal 150 karakters",
-                           widget=forms.Textarea()
-                           )
+        ))
+
+    text = forms.CharField(
+        label=_("Description"),
+        max_length=500,
+        help_text="Maximaal 500 karakters",
+        widget=MarkupTextarea(
+            attrs={'class': 'full count_characters',
+                   'data-maxchars': '500'}
+        ))
 
     @property
     def labels(self):
